pub struct NonParametric;Trait Implementations
Sourceimpl<E: Equation + Send + 'static> Algorithm<E, NonParametric> for NcnpagConfig
impl<E: Equation + Send + 'static> Algorithm<E, NonParametric> for NcnpagConfig
Sourcetype Output = NonParametricResult<E>
type Output = NonParametricResult<E>
The specific result struct (e.g.
NonParametricResult<E>).Sourcefn fit(
self,
problem: EstimationProblem<E, NonParametric>,
) -> Result<Self::Output>
fn fit( self, problem: EstimationProblem<E, NonParametric>, ) -> Result<Self::Output>
Consumes the configuration and the problem, runs the optimization to
completion, and returns the strictly-typed result.
Sourceimpl<E: Equation + Send + 'static> Algorithm<E, NonParametric> for NonParametricAlgorithm
impl<E: Equation + Send + 'static> Algorithm<E, NonParametric> for NonParametricAlgorithm
Sourcetype Output = NonParametricResult<E>
type Output = NonParametricResult<E>
The specific result struct (e.g.
NonParametricResult<E>).Sourcefn fit(
self,
problem: EstimationProblem<E, NonParametric>,
) -> Result<Self::Output>
fn fit( self, problem: EstimationProblem<E, NonParametric>, ) -> Result<Self::Output>
Consumes the configuration and the problem, runs the optimization to
completion, and returns the strictly-typed result.
Sourceimpl<E: Equation + Send + 'static> Algorithm<E, NonParametric> for NpagConfig
impl<E: Equation + Send + 'static> Algorithm<E, NonParametric> for NpagConfig
Sourcetype Output = NonParametricResult<E>
type Output = NonParametricResult<E>
The specific result struct (e.g.
NonParametricResult<E>).Sourcefn fit(
self,
problem: EstimationProblem<E, NonParametric>,
) -> Result<Self::Output>
fn fit( self, problem: EstimationProblem<E, NonParametric>, ) -> Result<Self::Output>
Consumes the configuration and the problem, runs the optimization to
completion, and returns the strictly-typed result.
Sourceimpl<E: Equation + Send + 'static> Algorithm<E, NonParametric> for NpmapConfig
impl<E: Equation + Send + 'static> Algorithm<E, NonParametric> for NpmapConfig
Sourcetype Output = NonParametricResult<E>
type Output = NonParametricResult<E>
The specific result struct (e.g.
NonParametricResult<E>).Sourcefn fit(
self,
problem: EstimationProblem<E, NonParametric>,
) -> Result<Self::Output>
fn fit( self, problem: EstimationProblem<E, NonParametric>, ) -> Result<Self::Output>
Consumes the configuration and the problem, runs the optimization to
completion, and returns the strictly-typed result.
Sourceimpl<E: Equation + Send + 'static> Algorithm<E, NonParametric> for NpodConfig
impl<E: Equation + Send + 'static> Algorithm<E, NonParametric> for NpodConfig
Sourcetype Output = NonParametricResult<E>
type Output = NonParametricResult<E>
The specific result struct (e.g.
NonParametricResult<E>).Sourcefn fit(
self,
problem: EstimationProblem<E, NonParametric>,
) -> Result<Self::Output>
fn fit( self, problem: EstimationProblem<E, NonParametric>, ) -> Result<Self::Output>
Consumes the configuration and the problem, runs the optimization to
completion, and returns the strictly-typed result.
Sourceimpl Clone for NonParametric
impl Clone for NonParametric
Sourcefn clone(&self) -> NonParametric
fn clone(&self) -> NonParametric
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NonParametric
impl Debug for NonParametric
Sourceimpl Framework for NonParametric
impl Framework for NonParametric
impl Copy for NonParametric