pub struct Parametric;Trait Implementations
Sourceimpl<E: Equation + Send + 'static> Algorithm<E, Parametric> for ParametricAlgorithm
impl<E: Equation + Send + 'static> Algorithm<E, Parametric> for ParametricAlgorithm
Sourcetype Output = ParametricResult<E>
type Output = ParametricResult<E>
The specific result struct (e.g.
NonParametricResult<E>).Sourcefn fit(self, _problem: EstimationProblem<E, Parametric>) -> Result<Self::Output>
fn fit(self, _problem: EstimationProblem<E, Parametric>) -> Result<Self::Output>
Consumes the configuration and the problem, runs the optimization to
completion, and returns the strictly-typed result.
Sourceimpl<E: Equation + Send + 'static> Algorithm<E, Parametric> for SaemConfig
impl<E: Equation + Send + 'static> Algorithm<E, Parametric> for SaemConfig
Sourcetype Output = ParametricResult<E>
type Output = ParametricResult<E>
The specific result struct (e.g.
NonParametricResult<E>).Sourcefn fit(self, problem: EstimationProblem<E, Parametric>) -> Result<Self::Output>
fn fit(self, problem: EstimationProblem<E, Parametric>) -> Result<Self::Output>
Consumes the configuration and the problem, runs the optimization to
completion, and returns the strictly-typed result.
Sourceimpl Clone for Parametric
impl Clone for Parametric
Sourcefn clone(&self) -> Parametric
fn clone(&self) -> Parametric
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Parametric
impl Debug for Parametric
Sourceimpl Framework for Parametric
impl Framework for Parametric
type ErrorModels = ResidualErrorModels
Sourcetype Prior = ParameterSpace<UnboundedParameter>
type Prior = ParameterSpace<UnboundedParameter>
The prior that seeds the algorithm. Read more
impl Copy for Parametric